pub fn run_inline_test(
rule: &CompiledRule,
source: &str,
) -> Result<InlineTestReport, RulesError>Expand description
Run rule against source and compare its matches with the fixture’s
inline // ruleid: / // ok: annotations.
pub fn run_inline_test(
rule: &CompiledRule,
source: &str,
) -> Result<InlineTestReport, RulesError>Run rule against source and compare its matches with the fixture’s
inline // ruleid: / // ok: annotations.